@@ -1,5 +1,5 @@
 #
-# Copyright 2018-2021 Elyra Authors
+# Copyright 2018-2022 Elyra Authors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,6 +15,7 @@
 #
 
 import json
+import os
 
 from jupyter_server.base.handlers import APIHandler
 from jupyter_server.utils import url_unescape
@@ -22,7 +23,6 @@ from tornado import web
 
 from elyra.contents.parser import ContentParser
 from elyra.util.http import HttpErrorMixin
-from elyra.util.path import get_absolute_path
 from elyra.util.path import get_expanded_path
 
 
@@ -44,9 +44,7 @@ class ContentHandler(HttpErrorMixin, APIHandler):
         self.log.debug(f"Parsing file: {path}")
 
         try:
-            root_dir = self.settings['server_root_dir']
-            absolute_path = get_absolute_path(get_expanded_path(root_dir), path)
-
+            absolute_path = self._get_absolute_path(path)
             properties = self.content_parser.parse(absolute_path)
 
             # TODO: Validation of model
@@ -61,3 +59,17 @@ class ContentHandler(HttpErrorMixin, APIHandler):
             self.log.debug(f"Could not parse '{path}': {str(e)}")
             empty_properties = {"env_vars": {}, "inputs": [], "outputs": []}
             self.finish(json.dumps(empty_properties))
+
+    def _get_absolute_path(self, path: str) -> str:
+        """Returns the absolute path of 'path' in relation to the configured root_dir.
+
+         Note: This version of `get_absolute_path` is used over the version in util/path.py because
+         'path' will have a leading `/` and therefore be considered absolute already when, within
+         this handler, it should always be a path relative to root_dir.
+         """
+
+        root_dir = get_expanded_path(self.settings['server_root_dir'])
+        if path[0] == '/':  # if path starts with a slash, use the follow characters so join can be performed
+            path = path[1:]
+        absolute_path = os.path.normpath(os.path.join(root_dir, path))
+        return absolute_path
