@@ -87,7 +87,9 @@ class MetadataManager(LoggingConfigurable):
                 self.log.warning(f"Fetch of instance '{invalid_instance.name}' "
                                  f"of schemaspace '{self.schemaspace}' "
                                  f"encountered an exception: {ex}")
-                if include_invalid:
+                if include_invalid and (not of_schema or invalid_instance.schema_name == of_schema):
+                    # Export invalid instances if requested and if a schema was not specified
+                    # or the specified schema matches the instance's schema.
                     invalid_instance.reason = ex.__class__.__name__
                     instances.append(invalid_instance)
         return instances
@@ -237,7 +239,7 @@ class MetadataManager(LoggingConfigurable):
                 self._rollback(name, Metadata.from_dict(self.schemaspace, metadata_dict), "create", ex)
             raise ex
 
-        return metadata_post_op
+        return self.get(name)  # Retrieve updated/new instance so load hook can be called
 
     def _rollback(self, name: str, orig_value: Union[Metadata, Dict], operation: str, exception: Exception):
         """Rolls back the original value depending on the operation.
