@@ -16,6 +16,7 @@
 from abc import abstractmethod
 from enum import Enum
 from importlib import import_module
+import json
 from logging import Logger
 from types import SimpleNamespace
 from typing import Any
@@ -26,6 +27,14 @@ from typing import Tuple
 
 from traitlets.config import LoggingConfigurable
 
+# Rather than importing only the CatalogEntry class needed in the Component parse
+# type hint below, the catalog_connector module must be imported in its
+# entirety in order to avoid a circular reference issue
+try:
+    from elyra.pipeline import catalog_connector
+except ImportError:
+    import sys
+    catalog_connector = sys.modules[__package__ + '.catalog_connector']
 from elyra.pipeline.runtime_type import RuntimeProcessorType
 
 
@@ -171,21 +180,22 @@ class Component(object):
                  name: str,
                  description: Optional[str],
                  catalog_type: str,
-                 source_identifier: Any,
+                 component_reference: Any,
                  definition: Optional[str] = None,
                  runtime_type: Optional[str] = None,
                  op: Optional[str] = None,
                  categories: Optional[List[str]] = None,
                  properties: Optional[List[ComponentParameter]] = None,
                  extensions: Optional[List[str]] = None,
-                 parameter_refs: Optional[dict] = None):
+                 parameter_refs: Optional[dict] = None,
+                 package_name: Optional[str] = None):
         """
         :param id: Unique identifier for a component
         :param name: The name of the component for display
         :param description: The description of the component
         :param catalog_type: Indicates the type of component definition resource
                               location; one of ['url', filename', 'directory]
-        :param source_identifier: Source information to help locate the component definition
+        :param component_reference: Source information to help locate the component definition
         :param definition: The content of the specification file for this component
         :param runtime_type: The runtime type of the component (e.g. KUBEFLOW_PIPELINES, APACHE_AIRFLOW, etc.)
         :param op: The operation name of the component; used by generic components in rendering the palette
@@ -193,6 +203,8 @@ class Component(object):
                            in the palette
         :param properties: The set of properties for the component
         :param extensions: The file extension used by the component
+        :param package_name: The fully qualified package name (excluding class name) of the file associated
+            with this component
         """
 
         if not id:
@@ -204,7 +216,7 @@ class Component(object):
         self._name = name
         self._description = description
         self._catalog_type = catalog_type
-        self._source_identifier = source_identifier
+        self._component_reference = component_reference
 
         self._definition = definition
         self._runtime_type = runtime_type
@@ -220,13 +232,14 @@ class Component(object):
             else:
                 parameter_refs = {}
 
-        if extensions and not parameter_refs.get('filehandler'):
+        if self._catalog_type == "elyra" and extensions and not parameter_refs.get('filehandler'):
             Component._log_warning(f"Component '{self._id}' specifies extensions '{extensions}' but \
                                    no entry in the 'parameter_ref' dictionary for 'filehandler' and \
                                    cannot participate in drag and drop functionality as a result.")
 
         self._extensions = extensions
         self._parameter_refs = parameter_refs
+        self._package_name = package_name
 
     @property
     def id(self) -> str:
@@ -245,14 +258,19 @@ class Component(object):
         return self._catalog_type
 
     @property
-    def source_identifier(self) -> Any:
-        return self._source_identifier
+    def component_reference(self) -> Any:
+        return self._component_reference
 
     @property
     def component_source(self) -> str:
-        return str({
+        """
+        Informational property consisting of the catalog type from which
+        this component originates and the reference information used to
+        locate it within that catalog.
+        """
+        return json.dumps({
             "catalog_type": self.catalog_type,
-            "component_ref": self.source_identifier
+            "component_ref": self.component_reference
         })
 
     @property
@@ -286,6 +304,12 @@ class Component(object):
     def parameter_refs(self) -> dict:
         return self._parameter_refs
 
+    @property
+    def import_statement(self) -> Optional[str]:
+        if not self._package_name:
+            return None
+        return f"from {self._package_name} import {self._name}"
+
     @property
     def input_properties(self) -> List[ComponentParameter]:
         return [prop for prop in self._properties if prop.data_type != 'outputpath']
@@ -294,6 +318,14 @@ class Component(object):
     def output_properties(self) -> List[ComponentParameter]:
         return [prop for prop in self._properties if prop.data_type == 'outputpath']
 
+    @property
+    def file_extension(self) -> Optional[str]:
+        """
+        The file extension of the definition file representing this
+        Component.
+        """
+        return self.extensions[0] if self.extensions else None
+
     @staticmethod
     def _log_warning(msg: str, logger: Optional[Logger] = None):
         if logger:
@@ -327,9 +359,9 @@ class ComponentParser(LoggingConfigurable):  # ABC
         return self._file_types
 
     @abstractmethod
-    def parse(self, registry_entry: SimpleNamespace) -> Optional[List[Component]]:
+    def parse(self, catalog_entry: 'catalog_connector.CatalogEntry') -> Optional[List[Component]]:
         """
-        Parse a component definition given in the registry entry and return
+        Parse a component definition given in the catalog entry and return
         a list of fully-qualified Component objects
         """
         raise NotImplementedError()
@@ -363,7 +395,7 @@ class ComponentParser(LoggingConfigurable):  # ABC
                 if data_type in ['dict', 'dictionary']:
                     data_type = "dictionary"
                     default_value = {}
-                elif data_type in ['list', 'set', 'array', 'arr']:
+                else:  # data_type is one of ['list', 'set', 'array', 'arr']
                     data_type = "list"
                     default_value = []
 
