@@ -1,5 +1,5 @@
 #
-# Copyright 2018-2021 Elyra Authors
+# Copyright 2018-2022 Elyra Authors
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -64,7 +64,7 @@ class ElyraEngine(NBClientEngine):
         # Nicely handle preprocessor arguments prioritizing values set by engine
         final_kwargs = merge_kwargs(
             safe_kwargs,
-            timeout=execution_timeout if execution_timeout else kwargs.get('timeout'),
+            timeout=execution_timeout or kwargs.get('timeout'),
             startup_timeout=start_timeout,
             kernel_name=kernel_name,
             log=logger,
@@ -72,8 +72,8 @@ class ElyraEngine(NBClientEngine):
             stdout_file=stdout_file,
             stderr_file=stderr_file,
         )
-        kernel_kwargs = dict()
-        kernel_kwargs['env'] = kwargs.get('kernel_env')
+
+        kernel_kwargs = {'env': kwargs.get('kernel_env')}
         # Only include kernel_name and set path if GatewayKernelManager will be used
         kernel_manager_class = final_kwargs.get('kernel_manager_class')
         if kernel_manager_class == 'jupyter_server.gateway.managers.GatewayKernelManager':
