@@ -19,12 +19,16 @@ from typing import Dict
 from typing import List
 from typing import Optional
 
+from jsonschema import validate
+from jsonschema import ValidationError
 import yaml
 
+from elyra.pipeline.catalog_connector import CatalogEntry
 from elyra.pipeline.component import Component
 from elyra.pipeline.component import ComponentParameter
 from elyra.pipeline.component import ComponentParser
 from elyra.pipeline.component import ControllerMap
+from elyra.pipeline.kfp.kfp_component_utils import component_yaml_schema
 from elyra.pipeline.runtime_type import RuntimeProcessorType
 
 
@@ -33,9 +37,9 @@ class KfpComponentParser(ComponentParser):
 
     component_platform: RuntimeProcessorType = RuntimeProcessorType.KUBEFLOW_PIPELINES
 
-    def parse(self, registry_entry: SimpleNamespace) -> Optional[List[Component]]:
+    def parse(self, catalog_entry: CatalogEntry) -> Optional[List[Component]]:
         # Get YAML object from component definition
-        component_yaml = self._read_component_yaml(registry_entry)
+        component_yaml = self._read_component_yaml(catalog_entry)
         if not component_yaml:
             return None
 
@@ -47,22 +51,18 @@ class KfpComponentParser(ComponentParser):
 
         component_properties = self._parse_properties(component_yaml)
 
-        component = Component(
-            id=registry_entry.component_id,
+        component = catalog_entry.get_component(
+            id=catalog_entry.id,
             name=component_yaml.get('name'),
             description=description,
-            catalog_type=registry_entry.catalog_type,
-            source_identifier=registry_entry.component_identifier,
-            definition=registry_entry.component_definition,
-            runtime_type=self.component_platform.name,
-            categories=registry_entry.categories,
-            properties=component_properties
+            properties=component_properties,
+            file_extension=self._file_types[0]
         )
 
         return [component]
 
     def _parse_properties(self, component_yaml: Dict[str, Any]) -> List[ComponentParameter]:
-        properties: List[ComponentParameter] = list()
+        properties: List[ComponentParameter] = []
 
         # NOTE: Currently no runtime-specific properties are needed
         # properties.extend(self.get_runtime_specific_properties())
@@ -162,17 +162,27 @@ class KfpComponentParser(ComponentParser):
             )
         ]
 
-    def _read_component_yaml(self, registry_entry: SimpleNamespace) -> Optional[Dict[str, Any]]:
+    def _read_component_yaml(self, catalog_entry: CatalogEntry) -> Optional[Dict[str, Any]]:
         """
         Convert component_definition string to YAML object
         """
         try:
-            return yaml.safe_load(registry_entry.component_definition)
+            results = yaml.safe_load(catalog_entry.entry_data.definition)
         except Exception as e:
             self.log.warning(f"Could not load YAML definition for component with identifying information: "
-                             f"'{str(registry_entry.component_identifier)}' -> {str(e)}")
+                             f"'{catalog_entry.entry_reference}' -> {str(e)}")
             return None
 
+        try:
+            # Validate against component YAML schema
+            validate(instance=results, schema=component_yaml_schema)
+        except ValidationError as ve:
+            self.log.warning(f"Invalid format of YAML definition for component with identifying information: "
+                             f"'{catalog_entry.entry_reference}' -> {str(ve)}")
+            return None
+
+        return results
+
     def _is_path_based_parameter(self, parameter_name: str, component_body: Dict[str, Any]) -> bool:
         """
         Check whether parameter is a KFP path parameter (as opposed to a value parameter)
