@@ -363,6 +363,7 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
             )
 
         return KfpPipelineProcessorResponse(
+            run_id=run.id,
             run_url=f"{api_endpoint}/#/runs/details/{run.id}",
             object_storage_url=f"{cos_endpoint}",
             object_storage_path=f"/{cos_bucket}/{cos_directory}",
@@ -619,9 +620,16 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
                         operation.component_params_as_dict.pop(parameter, None)
 
                     # Create ContainerOp instance and assign appropriate user-provided name
-                    container_op = factory_function(**operation.component_params_as_dict)
+                    sanitized_component_params = {
+                        self._sanitize_param_name(name): value
+                        for name, value in operation.component_params_as_dict.items()
+                    }
+                    container_op = factory_function(**sanitized_component_params)
                     container_op.set_display_name(operation.name)
 
+                    if operation.doc:
+                        container_op.add_pod_annotation("elyra/node-user-doc", operation.doc)
+
                     target_ops[operation.id] = container_op
                 except Exception as e:
                     # TODO Fix error messaging and break exceptions down into categories
@@ -689,7 +697,39 @@ class KfpPipelineProcessor(RuntimePipelineProcessor):
         """
         return re.sub('-+', '-', re.sub('[^-_0-9A-Za-z ]+', '-', name)).lstrip('-').rstrip('-')
 
+    @staticmethod
+    def _sanitize_param_name(name: str) -> str:
+        """
+        Sanitize a component parameter name.
+
+        Behavior is mirrored from how Kubeflow 1.X sanitizes identifier names:
+        - https://github.com/kubeflow/pipelines/blob/1.8.1/sdk/python/kfp/components/_naming.py#L32-L42
+        - https://github.com/kubeflow/pipelines/blob/1.8.1/sdk/python/kfp/components/_naming.py#L49-L50
+        """
+        normalized_name = name.lower()
+
+        # remove non-word characters
+        normalized_name = re.sub(r'[\W_]', ' ', normalized_name)
+
+        # no double spaces, leading or trailing spaces
+        normalized_name = re.sub(' +', ' ', normalized_name).strip()
+
+        # no leading digits
+        if re.match(r'\d', normalized_name):
+            normalized_name = 'n' + normalized_name
+
+        return normalized_name.replace(' ', '_')
+
 
 class KfpPipelineProcessorResponse(PipelineProcessorResponse):
     _type = RuntimeProcessorType.KUBEFLOW_PIPELINES
     _name = 'kfp'
+
+    def __init__(self, run_id, run_url, object_storage_url, object_storage_path):
+        super().__init__(run_url, object_storage_url, object_storage_path)
+        self.run_id = run_id
+
+    def to_json(self):
+        response = super().to_json()
+        response['run_id'] = self.run_id
+        return response
