@@ -13,8 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+import json
 import os
-from types import SimpleNamespace
+from subprocess import CompletedProcess
+from subprocess import run
 
 from conftest import AIRFLOW_COMPONENT_CACHE_INSTANCE
 from conftest import TEST_CATALOG_NAME
@@ -22,10 +24,12 @@ import jupyter_core.paths
 import pytest
 
 from elyra.metadata.metadata import Metadata
+from elyra.pipeline.catalog_connector import CatalogEntry
 from elyra.pipeline.catalog_connector import FilesystemComponentCatalogConnector
 from elyra.pipeline.catalog_connector import UrlComponentCatalogConnector
 from elyra.pipeline.component import ComponentParser
 from elyra.pipeline.component_catalog import ComponentCache
+from elyra.pipeline.component_metadata import ComponentCatalogMetadata
 from elyra.pipeline.runtime_type import RuntimeProcessorType
 
 COMPONENT_CATALOG_DIRECTORY = os.path.join(jupyter_core.paths.ENV_JUPYTER_PATH[0], 'components')
@@ -45,22 +49,16 @@ def _get_resource_path(filename):
     return resource_path
 
 
-@pytest.mark.parametrize('component_cache_instance', [AIRFLOW_COMPONENT_CACHE_INSTANCE], indirect=True)
-def test_component_catalog_can_load_components_from_registries(component_cache_instance):
-    components = ComponentCache.instance().get_all_components(RUNTIME_PROCESSOR)
+@pytest.mark.parametrize('catalog_instance', [AIRFLOW_COMPONENT_CACHE_INSTANCE], indirect=True)
+def test_component_catalog_can_load_components_from_registries(catalog_instance, component_cache):
+    components = component_cache.get_all_components(RUNTIME_PROCESSOR)
     assert len(components) > 0
 
 
-def test_modify_component_catalogs(metadata_manager_with_teardown):
-    # Initialize a ComponentCache instance and wait for all worker threads to compete
-    component_catalog = ComponentCache.instance()
-    component_catalog.wait_for_all_cache_updates()
-
-    # Get initial set of components from the current active registries
-    initial_components = component_catalog.get_all_components(RUNTIME_PROCESSOR)
-
-    # Components must be sorted by id for the equality comparison with later component lists
-    initial_components = sorted(initial_components, key=lambda component: component.id)
+@pytest.mark.parametrize('create_inprocess', [True, False])
+async def test_modify_component_catalogs(component_cache, metadata_manager_with_teardown, create_inprocess):
+    # Get initial set of components
+    initial_components = component_cache.get_all_components(RUNTIME_PROCESSOR)
 
     # Create new registry instance with a single URL-based component
     urls = ["https://raw.githubusercontent.com/elyra-ai/elyra/master/elyra/tests/pipeline/resources/components/"
@@ -77,17 +75,23 @@ def test_modify_component_catalogs(metadata_manager_with_teardown):
                                  display_name="New Test Registry",
                                  metadata=instance_metadata)
 
-    metadata_manager_with_teardown.create(TEST_CATALOG_NAME, registry_instance)
+    if create_inprocess:
+        metadata_manager_with_teardown.create(TEST_CATALOG_NAME, registry_instance)
+    else:
+        res: CompletedProcess = run(['elyra-metadata', 'install', 'component-catalogs',
+                                     f'--schema_name={registry_instance.schema_name}',
+                                     f'--json={registry_instance.to_json()}',
+                                     f'--name={TEST_CATALOG_NAME}'])
+        assert res.returncode == 0
 
     # Wait for update to complete
-    component_catalog.wait_for_all_cache_updates()
+    component_cache.wait_for_all_cache_tasks()
 
     # Get new set of components from all active registries, including added test registry
-    added_components = component_catalog.get_all_components(RUNTIME_PROCESSOR)
-    added_components = sorted(added_components, key=lambda component: component.id)
-    assert len(added_components) > len(initial_components)
+    components_after_create = component_cache.get_all_components(RUNTIME_PROCESSOR)
+    assert len(components_after_create) == len(initial_components) + 3
 
-    added_component_names = [component.name for component in added_components]
+    added_component_names = [component.name for component in components_after_create]
     assert 'TestOperator' in added_component_names
     assert 'TestOperatorNoInputs' not in added_component_names
 
@@ -97,14 +101,13 @@ def test_modify_component_catalogs(metadata_manager_with_teardown):
     metadata_manager_with_teardown.update(TEST_CATALOG_NAME, registry_instance)
 
     # Wait for update to complete
-    component_catalog.wait_for_all_cache_updates()
+    component_cache.wait_for_all_cache_tasks()
 
     # Get set of components from all active registries, including modified test registry
-    modified_components = component_catalog.get_all_components(RUNTIME_PROCESSOR)
-    modified_components = sorted(modified_components, key=lambda component: component.id)
-    assert len(modified_components) > len(added_components)
+    components_after_update = component_cache.get_all_components(RUNTIME_PROCESSOR)
+    assert len(components_after_update) == len(initial_components) + 4
 
-    modified_component_names = [component.name for component in modified_components]
+    modified_component_names = [component.name for component in components_after_update]
     assert 'TestOperator' in modified_component_names
     assert 'TestOperatorNoInputs' in modified_component_names
 
@@ -112,30 +115,17 @@ def test_modify_component_catalogs(metadata_manager_with_teardown):
     metadata_manager_with_teardown.remove(TEST_CATALOG_NAME)
 
     # Wait for update to complete
-    component_catalog.wait_for_all_cache_updates()
+    component_cache.wait_for_all_cache_tasks()
 
-    post_delete_components = component_catalog.get_all_components(RUNTIME_PROCESSOR)
-    post_delete_components = sorted(post_delete_components, key=lambda component: component.id)
-    assert len(post_delete_components) == len(initial_components)
-
-    # Check that the list of component ids is the same as before addition of the test registry
-    initial_component_ids = [component.id for component in initial_components]
-    post_delete_component_ids = [component.id for component in post_delete_components]
-    assert post_delete_component_ids == initial_component_ids
-
-    # Check that component palette is the same as before addition of the test registry
-    initial_palette = ComponentCache.to_canvas_palette(initial_components)
-    post_delete_palette = ComponentCache.to_canvas_palette(post_delete_components)
-    assert initial_palette == post_delete_palette
+    # Check that components remaining after delete are the same as before the new catalog was added
+    components_after_remove = component_cache.get_all_components(RUNTIME_PROCESSOR)
+    assert len(components_after_remove) == len(initial_components)
 
 
-def test_directory_based_component_catalog(metadata_manager_with_teardown):
-    # Initialize a ComponentCache instance and wait for all worker threads to compete
-    component_catalog = ComponentCache.instance()
-    component_catalog.wait_for_all_cache_updates()
-
-    # Get initial set of components from the current active registries
-    initial_components = component_catalog.get_all_components(RUNTIME_PROCESSOR)
+@pytest.mark.parametrize('create_inprocess', [True, False])
+async def test_directory_based_component_catalog(component_cache, metadata_manager_with_teardown, create_inprocess):
+    # Get initial set of components
+    initial_components = component_cache.get_all_components(RUNTIME_PROCESSOR)
 
     # Create new directory-based registry instance with components in ../../test/resources/components
     registry_path = _get_resource_path('')
@@ -150,46 +140,58 @@ def test_directory_based_component_catalog(metadata_manager_with_teardown):
                                  display_name="New Test Registry",
                                  metadata=instance_metadata)
 
-    metadata_manager_with_teardown.create(TEST_CATALOG_NAME, registry_instance)
+    if create_inprocess:
+        metadata_manager_with_teardown.create(TEST_CATALOG_NAME, registry_instance)
+    else:
+        res: CompletedProcess = run(['elyra-metadata', 'install', 'component-catalogs',
+                                     f'--schema_name={registry_instance.schema_name}',
+                                     f'--json={registry_instance.to_json()}',
+                                     f'--name={TEST_CATALOG_NAME}'])
+        assert res.returncode == 0
 
     # Wait for update to complete
-    component_catalog.wait_for_all_cache_updates()
+    component_cache.wait_for_all_cache_tasks()
 
     # Get new set of components from all active registries, including added test registry
-    added_components = component_catalog.get_all_components(RUNTIME_PROCESSOR)
-    assert len(added_components) > len(initial_components)
+    components_after_create = component_cache.get_all_components(RUNTIME_PROCESSOR)
+    assert len(components_after_create) == len(initial_components) + 5
 
     # Check that all relevant components from the new registry have been added
-    added_component_names = [component.name for component in added_components]
+    added_component_names = [component.name for component in components_after_create]
     assert 'TestOperator' in added_component_names
     assert 'TestOperatorNoInputs' in added_component_names
 
+    # Delete the test registry and wait for updates to complete
+    metadata_manager_with_teardown.remove(TEST_CATALOG_NAME)
+    component_cache.wait_for_all_cache_tasks()
+
 
 def test_parse_airflow_component_file():
     # Define the appropriate reader for a filesystem-type component definition
     airflow_supported_file_types = [".py"]
     reader = FilesystemComponentCatalogConnector(airflow_supported_file_types)
 
+    # Read contents of given path
     path = _get_resource_path('airflow_test_operator.py')
+    catalog_entry_data = {"path": path}
 
-    # Read contents of given path -- read_component_definition() returns a
-    # a dictionary of component definition content indexed by path
-    component_definition = reader.read_catalog_entry({"path": path}, {})
-
-    # Build entry for parsing
+    # Construct a catalog instance
     catalog_type = "local-file-catalog"
-    entry = {
-        "component_id": reader.get_unique_component_hash(catalog_type, {"path": path}, ["path"]),
-        "catalog_type": catalog_type,
-        "categories": ["Test"],
-        "component_definition": component_definition,
-        "component_identifier": {"path": path}
-    }
-    component_entry = SimpleNamespace(**entry)
+    catalog_instance = ComponentCatalogMetadata(
+        schema_name=catalog_type,
+        metadata={
+            "categories": ['Test'],
+            "runtime_type": RUNTIME_PROCESSOR.name
+        }
+    )
+
+    # Build the catalog entry data structures required for parsing
+    entry_data = reader.get_entry_data(catalog_entry_data, {})
+    catalog_entry = CatalogEntry(entry_data, catalog_entry_data, catalog_instance, ['path'])
 
     # Parse the component entry
     parser = ComponentParser.create_instance(platform=RUNTIME_PROCESSOR)
-    components = parser.parse(component_entry)
+    components = parser.parse(catalog_entry)
     assert len(components) == 3  # TestOperator, DeriveFromTestOperator, and DeriveFromImportedOperator
 
     # Split components list into its constituent operators
@@ -238,7 +240,7 @@ def test_parse_airflow_component_file():
     # Ensure system parameters are not prefixed and hold correct values
     assert properties_json['current_parameters']['label'] == ''
 
-    component_source = str({"catalog_type": catalog_type, "component_ref": component_entry.component_identifier})
+    component_source = json.dumps({"catalog_type": catalog_type, "component_ref": catalog_entry.entry_reference})
     assert properties_json['current_parameters']['component_source'] == component_source
 
     # Ensure component parameters are prefixed with 'elyra_' and values are as expected
@@ -285,6 +287,13 @@ def test_parse_airflow_component_file():
                                                                    "(type: a list of strings)"
     assert get_parameter_description('elyra_fallback_type') == "(type: str)"
 
+    # Ensure that a long description with line wrapping and a backslash escape has rendered
+    # (and hence did not raise an error during json.loads in the properties API request)
+    parsed_description = """a string parameter with a very long description
+        that wraps lines and also has an escaped underscore in it, as shown here: (\_)  # noqa W605"""
+    modified_description = parsed_description.replace("\n", " ") + " (type: str)"  # modify desc acc. to parser rules
+    assert get_parameter_description('elyra_long_description_property') == modified_description
+
     # Retrieve properties for DeriveFromTestOperator
     # DeriveFromTestOperator includes type hints for all init arguments
     properties_json = ComponentCache.to_canvas_properties(derive_test_op)
@@ -340,30 +349,31 @@ def test_parse_airflow_component_file():
 
 
 def test_parse_airflow_component_url():
-    # Define the appropriate reader for a Url-type component definition
+    # Define the appropriate reader for a URL-type component definition
     airflow_supported_file_types = [".py"]
     reader = UrlComponentCatalogConnector(airflow_supported_file_types)
 
+    # Read contents of given path
     url = 'https://raw.githubusercontent.com/apache/airflow/1.10.15/airflow/operators/bash_operator.py'  # noqa: E501
+    catalog_entry_data = {"url": url}
 
-    # Read contents of given path -- read_component_definition() returns a
-    # a dictionary of component definition content indexed by path
-    component_definition = reader.read_catalog_entry({"url": url}, {})
-
-    # Build entry for parsing
+    # Construct a catalog instance
     catalog_type = "url-catalog"
-    entry = {
-        "component_id": reader.get_unique_component_hash(catalog_type, {"url": url}, ["url"]),
-        "catalog_type": catalog_type,
-        "categories": ["Test"],
-        "component_definition": component_definition,
-        "component_identifier": {"url": url}
-    }
-    component_entry = SimpleNamespace(**entry)
+    catalog_instance = ComponentCatalogMetadata(
+        schema_name=catalog_type,
+        metadata={
+            "categories": ['Test'],
+            "runtime_type": RUNTIME_PROCESSOR.name
+        }
+    )
+
+    # Build the catalog entry data structures required for parsing
+    entry_data = reader.get_entry_data(catalog_entry_data, {})
+    catalog_entry = CatalogEntry(entry_data, catalog_entry_data, catalog_instance, ['url'])
 
     # Parse the component entry
     parser = ComponentParser.create_instance(platform=RUNTIME_PROCESSOR)
-    component = parser.parse(component_entry)[0]
+    component = parser.parse(catalog_entry)[0]
     properties_json = ComponentCache.to_canvas_properties(component)
 
     # Ensure component parameters are prefixed, and system parameters are not, and hold correct values
@@ -374,7 +384,7 @@ def test_parse_airflow_component_url():
         property_dict = properties_json['current_parameters'][param_name]
         return property_dict[property_dict['activeControl']]
 
-    component_source = str({"catalog_type": catalog_type, "component_ref": component_entry.component_identifier})
+    component_source = json.dumps({"catalog_type": catalog_type, "component_ref": catalog_entry.entry_reference})
     assert properties_json['current_parameters']['component_source'] == component_source
     assert get_parameter('elyra_bash_command') == ''
     assert get_parameter('elyra_xcom_push') is True
@@ -387,26 +397,27 @@ def test_parse_airflow_component_file_no_inputs():
     airflow_supported_file_types = [".py"]
     reader = FilesystemComponentCatalogConnector(airflow_supported_file_types)
 
+    # Read contents of given path
     path = _get_resource_path('airflow_test_operator_no_inputs.py')
+    catalog_entry_data = {"path": path}
 
-    # Read contents of given path -- read_component_definition() returns a
-    # a dictionary of component definition content indexed by path
-    component_definition = reader.read_catalog_entry({"path": path}, {})
-
-    # Build entry for parsing
+    # Construct a catalog instance
     catalog_type = "local-file-catalog"
-    entry = {
-        "component_id": reader.get_unique_component_hash(catalog_type, {"path": path}, ["path"]),
-        "catalog_type": catalog_type,
-        "categories": ["Test"],
-        "component_definition": component_definition,
-        "component_identifier": {"path": path}
-    }
-    component_entry = SimpleNamespace(**entry)
+    catalog_instance = ComponentCatalogMetadata(
+        schema_name=catalog_type,
+        metadata={
+            "categories": ['Test'],
+            "runtime_type": RUNTIME_PROCESSOR.name
+        }
+    )
+
+    # Build the catalog entry data structures required for parsing
+    entry_data = reader.get_entry_data(catalog_entry_data, {})
+    catalog_entry = CatalogEntry(entry_data, catalog_entry_data, catalog_instance, ['path'])
 
     # Parse the component entry
     parser = ComponentParser.create_instance(platform=RUNTIME_PROCESSOR)
-    no_input_op = parser.parse(component_entry)[0]
+    no_input_op = parser.parse(catalog_entry)[0]
     properties_json = ComponentCache.to_canvas_properties(no_input_op)
 
     # Properties JSON should only include the two parameters common to every
@@ -424,7 +435,7 @@ def test_parse_airflow_component_file_no_inputs():
     # Ensure that template still renders the two common parameters correctly
     assert properties_json['current_parameters']['label'] == ""
 
-    component_source = str({"catalog_type": catalog_type, "component_ref": component_entry.component_identifier})
+    component_source = json.dumps({"catalog_type": catalog_type, "component_ref": catalog_entry.entry_reference})
     assert properties_json['current_parameters']['component_source'] == component_source
 
 
@@ -439,5 +450,5 @@ async def test_parse_components_invalid_url(invalid_url):
     reader = UrlComponentCatalogConnector(airflow_supported_file_types)
 
     # Get path to an invalid component definition file and read contents
-    component_definition = reader.read_catalog_entry({"url": invalid_url}, {})
-    assert component_definition is None
+    entry_data = reader.get_entry_data({"url": invalid_url}, {})
+    assert entry_data is None
