@@ -106,8 +106,10 @@ def test_basic_pipeline_structure_with_scripts(validation_manager, load_pipeline
     assert not response.to_json().get('issues')
 
 
-@pytest.mark.parametrize('component_cache_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
-async def test_invalid_runtime_node_kubeflow(validation_manager, load_pipeline, component_cache_instance):
+@pytest.mark.parametrize('catalog_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
+async def test_invalid_runtime_node_kubeflow(validation_manager,
+                                             load_pipeline,
+                                             catalog_instance):
     pipeline, response = load_pipeline('kf_invalid_node_op.pipeline')
     node_id = "eace43f8-c4b1-4a25-b331-d57d4fc29426"
 
@@ -118,16 +120,17 @@ async def test_invalid_runtime_node_kubeflow(validation_manager, load_pipeline,
                                                      pipeline_runtime='kfp')
 
     issues = response.to_json().get('issues')
+    print(issues)
     assert len(issues) == 1
     assert issues[0]['severity'] == 1
     assert issues[0]['type'] == 'invalidNodeType'
     assert issues[0]['data']['nodeID'] == node_id
 
 
-@pytest.mark.parametrize('component_cache_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
+@pytest.mark.parametrize('catalog_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
 async def test_invalid_runtime_node_kubeflow_with_supernode(validation_manager,
                                                             load_pipeline,
-                                                            component_cache_instance):
+                                                            catalog_instance):
     pipeline, response = load_pipeline('kf_invalid_node_op_with_supernode.pipeline')
     node_id = "98aa7270-639b-42a4-9a07-b31cd0fa3205"
     pipeline_id = "00304a2b-dec4-4a73-ab4a-6830f97d7855"
@@ -191,11 +194,11 @@ async def test_invalid_node_op_with_airflow(validation_manager, load_pipeline):
     assert issues[0]['data']['nodeID'] == node_id
 
 
-async def test_invalid_node_property_structure(monkeypatch, load_pipeline):
+async def test_invalid_node_property_structure(validation_manager, monkeypatch, load_pipeline):
     pipeline, response = load_pipeline('generic_invalid_node_property_structure.pipeline')
     node_id = '88ab83dc-d5f0-443a-8837-788ed16851b7'
     node_property = 'runtime_image'
-    pvm = PipelineValidationManager.instance()
+    pvm = validation_manager
 
     monkeypatch.setattr(pvm, "_validate_filepath", lambda node_id, node_label,
                         property_name, filename, response: True)
@@ -217,12 +220,15 @@ async def test_invalid_node_property_structure(monkeypatch, load_pipeline):
     assert issues[0]['data']['nodeID'] == node_id
 
 
-@pytest.mark.parametrize('component_cache_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
-async def test_missing_node_property_for_kubeflow_pipeline(monkeypatch, load_pipeline, component_cache_instance):
+@pytest.mark.parametrize('catalog_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
+async def test_missing_node_property_for_kubeflow_pipeline(validation_manager,
+                                                           monkeypatch,
+                                                           load_pipeline,
+                                                           catalog_instance):
     pipeline, response = load_pipeline('kf_invalid_node_property_in_component.pipeline')
     node_id = 'fe08b42d-bd8c-4e97-8010-0503a3185427'
     node_property = "notebook"
-    pvm = PipelineValidationManager.instance()
+    pvm = validation_manager
 
     monkeypatch.setattr(pvm, "_validate_filepath", lambda node_id, file_dir, property_name, filename, response: True)
 
@@ -524,8 +530,11 @@ def test_pipeline_invalid_single_cycle_kfp_with_supernode(validation_manager, lo
     assert issues[0]['type'] == 'circularReference'
 
 
-@pytest.mark.parametrize('component_cache_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
-async def test_pipeline_kfp_inputpath_parameter(validation_manager, load_pipeline, component_cache_instance):
+@pytest.mark.parametrize('catalog_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
+async def test_pipeline_kfp_inputpath_parameter(validation_manager,
+                                                load_pipeline,
+                                                catalog_instance,
+                                                component_cache):
     pipeline, response = load_pipeline('kf_inputpath_parameter.pipeline')
     pipeline_definition = PipelineDefinition(pipeline_definition=pipeline)
     await validation_manager._validate_node_properties(pipeline_definition=pipeline_definition,
@@ -537,10 +546,11 @@ async def test_pipeline_kfp_inputpath_parameter(validation_manager, load_pipelin
     assert len(issues) == 0
 
 
-@pytest.mark.parametrize('component_cache_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
+@pytest.mark.parametrize('catalog_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
 async def test_pipeline_invalid_kfp_inputpath_parameter(validation_manager,
                                                         load_pipeline,
-                                                        component_cache_instance):
+                                                        catalog_instance,
+                                                        component_cache):
     invalid_key_node_id = "089a12df-fe2f-4fcb-ae37-a1f8a6259ca1"
     missing_param_node_id = "e8820c55-dc79-46d1-b32e-924fa5d70d2a"
     pipeline, response = load_pipeline('kf_invalid_inputpath_parameter.pipeline')
@@ -561,10 +571,11 @@ async def test_pipeline_invalid_kfp_inputpath_parameter(validation_manager,
     assert issues[1]['data']['nodeID'] == missing_param_node_id
 
 
-@pytest.mark.parametrize('component_cache_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
+@pytest.mark.parametrize('catalog_instance', [KFP_COMPONENT_CACHE_INSTANCE], indirect=True)
 async def test_pipeline_invalid_kfp_inputpath_missing_connection(validation_manager,
                                                                  load_pipeline,
-                                                                 component_cache_instance):
+                                                                 catalog_instance,
+                                                                 component_cache):
     invalid_node_id = "5b78ea0a-e5fc-4022-94d4-7b9dc170d794"
     pipeline, response = load_pipeline('kf_invalid_inputpath_missing_connection.pipeline')
     pipeline_definition = PipelineDefinition(pipeline_definition=pipeline)
@@ -581,10 +592,11 @@ async def test_pipeline_invalid_kfp_inputpath_missing_connection(validation_mana
     assert issues[0]['data']['nodeID'] == invalid_node_id
 
 
-@pytest.mark.parametrize('component_cache_instance', [AIRFLOW_COMPONENT_CACHE_INSTANCE], indirect=True)
+@pytest.mark.parametrize('catalog_instance', [AIRFLOW_COMPONENT_CACHE_INSTANCE], indirect=True)
 async def test_pipeline_aa_parent_node_missing_xcom_push(validation_manager,
                                                          load_pipeline,
-                                                         component_cache_instance):
+                                                         catalog_instance,
+                                                         component_cache):
 
     invalid_node_id = 'b863d458-21b5-4a46-8420-5a814b7bd525'
     invalid_operator = 'BashOperator'
